==> zope.app.apidoc_3.7.5.orig.tar.gz: zope.app.apidoc-3.7.5/src/zope/app/apidoc/typemodule/browser.py <==
##############################################################################
#
# Copyright (c) 2004 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Browser Views for Interface Types

$Id: browser.py 113308 2010-06-10 01:09:36Z srichter $
"""
__docformat__ = 'restructuredtext'
from type import TypeInterface

from zope.security.proxy import isinstance, removeSecurityProxy
from zope.traversing.api import getName
from zope.app.apidoc.browser.utilities import findAPIDocumentationRootURL


class Menu(object):
    """Menu View Helper Class"""

    def getMenuTitle(self, node):
        """Return the title of the node that is displayed in the menu."""
        if isinstance(node.context, TypeInterface):
            iface = node.context.interface
        else:
            iface = node.context
        # Interfaces have no security declarations, so we have to unwrap.
        return removeSecurityProxy(iface).getName()

    def getMenuLink(self, node):
        """Return the HTML link of the node that is displayed in the menu."""
        root_url = findAPIDocumentationRootURL(self.context, self.request)
        return '%s/Interface/%s/index.html' % (root_url, getName(node.context))

==> zope.app.apidoc-4.3.0.tar.gz: zope.app.apidoc-4.3.0/src/zope/app/apidoc/typemodule/browser.py <==
##############################################################################
#
# Copyright (c) 2004 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Browser Views for Interface Types

"""
__docformat__ = 'restructuredtext'
from zope.app.apidoc.typemodule.type import TypeInterface

from zope.security.proxy import isinstance, removeSecurityProxy
from zope.traversing.api import getName
from zope.app.apidoc.browser.utilities import findAPIDocumentationRootURL


class Menu(object):
    """Menu View Helper Class"""

    context = None
    request = None

    def getMenuTitle(self, node):
        """Return the title of the node that is displayed in the menu."""
        if isinstance(node.context, TypeInterface):
            iface = node.context.interface
        else:
            iface = node.context
        # Interfaces have no security declarations, so we have to unwrap.
        return removeSecurityProxy(iface).getName()

    def getMenuLink(self, node):
        """Return the HTML link of the node that is displayed in the menu."""
        root_url = findAPIDocumentationRootURL(self.context, self.request)
        return '%s/Interface/%s/index.html' % (root_url, getName(node.context))
